@@ -62,12 +62,13 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicReference;
 import com.openexchange.exception.OXException;
-import com.openexchange.log.Log;
 import com.openexchange.realtime.Component;
 import com.openexchange.realtime.Component.EvictionPolicy;
 import com.openexchange.realtime.ComponentHandle;
+import com.openexchange.realtime.cleanup.GlobalRealtimeCleanup;
 import com.openexchange.realtime.dispatch.MessageDispatcher;
 import com.openexchange.realtime.group.commands.LeaveCommand;
+import com.openexchange.realtime.group.osgi.GroupServiceRegistry;
 import com.openexchange.realtime.packet.ID;
 import com.openexchange.realtime.packet.IDEventHandler;
 import com.openexchange.realtime.packet.Message;
@@ -76,7 +77,7 @@ import com.openexchange.realtime.payload.PayloadElement;
 import com.openexchange.realtime.payload.PayloadTree;
 import com.openexchange.realtime.payload.PayloadTreeNode;
 import com.openexchange.realtime.util.ActionHandler;
-import com.openexchange.server.ServiceLookup;
+import com.openexchange.server.ServiceExceptionCode;
 
 /**
  * A {@link GroupDispatcher} is a utility superclass for implmenting chat room like functionality. Clients can join and leave the chat room,
@@ -89,10 +90,9 @@ import com.openexchange.server.ServiceLookup;
 public class GroupDispatcher implements ComponentHandle {
 
     /** The logger constant. */
-    static final org.apache.commons.logging.Log LOG = Log.loggerFor(GroupDispatcher.class);
+    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(GroupDispatcher.class);
 
-    /** The <code>ServiceLookup</code> reference. */
-    public static final AtomicReference<ServiceLookup> SERVICE_REF = new AtomicReference<ServiceLookup>();
+    public static final AtomicReference<GroupManager> GROUPMANAGER_REF = new AtomicReference<GroupManager>();
 
     /** The collection of IDs that might be concurrently accessed */
     private final AtomicReference<Set<ID>> idsRef = new AtomicReference<Set<ID>>(Collections.<ID> emptySet());
@@ -100,14 +100,14 @@ public class GroupDispatcher implements ComponentHandle {
     private final Map<ID, String> stamps = new ConcurrentHashMap<ID, String>();
 
     /** ID of the group */
-    private final ID id;
+    private final ID groupId;
 
     /** Sequence numer */
     private final AtomicLong sequenceNumber = new AtomicLong();
 
     /** Action handler */
     private final ActionHandler handler;
-    
+
     private boolean isDisposed = false;
 
     /**
@@ -127,7 +127,7 @@ public class GroupDispatcher implements ComponentHandle {
      */
     public GroupDispatcher(ID id, ActionHandler handler) {
         super();
-        this.id = id;
+        groupId = id;
         this.handler = handler;
         final AtomicReference<Set<ID>> idsRef = this.idsRef;
         id.on(ID.Events.DISPOSE, new IDEventHandler() {
@@ -152,7 +152,7 @@ public class GroupDispatcher implements ComponentHandle {
                         onDispose(memberId != null ? memberId : id);
                     }
                 } catch (OXException e) {
-                    LOG.error(e.getMessage(), e);
+                    LOG.error("", e);
                 }
             }
         });
@@ -167,7 +167,7 @@ public class GroupDispatcher implements ComponentHandle {
      */
     @Override
     public void process(Stanza stanza) throws OXException {
-        stanza.trace("Arrived in group dispatcher: " + id);
+        stanza.trace("Arrived in group dispatcher: " + groupId);
         if (!handleGroupCommand(stanza)) {
             processStanza(stanza);
         }
@@ -213,7 +213,7 @@ public class GroupDispatcher implements ComponentHandle {
      * Send a copy of the stanza to all members of this group, excluding the ones provided as the rest of the arguments.
      */
     public void relayToAll(Stanza stanza, Stanza inResponseTo, ID... excluded) throws OXException {
-        MessageDispatcher dispatcher = SERVICE_REF.get().getService(MessageDispatcher.class);
+        MessageDispatcher dispatcher = GroupServiceRegistry.getInstance().getService(MessageDispatcher.class);
         Set<ID> ex = new HashSet<ID>(Arrays.asList(excluded));
         // Iterate over snapshot
         for (ID id : idsRef.get()) {
@@ -249,7 +249,7 @@ public class GroupDispatcher implements ComponentHandle {
      * Relay this message just to a specific receiver
      */
     public void relayToID(Stanza stanza, ID id) throws OXException {
-        MessageDispatcher dispatcher = SERVICE_REF.get().getService(MessageDispatcher.class);
+        MessageDispatcher dispatcher = GroupServiceRegistry.getInstance().getService(MessageDispatcher.class);
 
         // Send a copy of the stanza
         Stanza copy = copyFor(stanza, id);
@@ -262,7 +262,7 @@ public class GroupDispatcher implements ComponentHandle {
      */
     public void send(Stanza stanza) throws OXException {
         stamp(stanza);
-        MessageDispatcher dispatcher = SERVICE_REF.get().getService(MessageDispatcher.class);
+        MessageDispatcher dispatcher = GroupServiceRegistry.getInstance().getService(MessageDispatcher.class);
 
         dispatcher.send(stanza);
     }
@@ -278,12 +278,14 @@ public class GroupDispatcher implements ComponentHandle {
      */
     public void join(ID id, String stamp) {
         if (idsRef.get().contains(id)) {
+            LOG.info("{} is already a member of {}.", id, groupId);
             return;
         }
 
         beforeJoin(id);
 
         if (!mayJoin(id)) {
+            LOG.info("{} is already a member of {}.", id, groupId);
             return;
         }
 
@@ -301,9 +303,7 @@ public class GroupDispatcher implements ComponentHandle {
             added = ids.add(id);
         } while (!idsRef.compareAndSet(expected, ids));
 
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("joining:" + id.toString());
-        }
+        LOG.debug("{} is joining {},", id, groupId);
 
         stamps.put(id, stamp);
         id.on(ID.Events.DISPOSE, LEAVE);
@@ -311,6 +311,12 @@ public class GroupDispatcher implements ComponentHandle {
             firstJoined(id);
         }
         if (added) {
+            GroupManager groupManager = GROUPMANAGER_REF.get();
+            if(groupManager == null) {
+                LOG.error("GroupManager reference unset.");
+            } else {
+                groupManager.add(id, groupId);
+            }
             onJoin(id);
         }
     }
@@ -322,9 +328,7 @@ public class GroupDispatcher implements ComponentHandle {
     public void leave(ID id) throws OXException {
         beforeLeave(id);
 
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("leaving:" + id.toString());
-        }
+        LOG.debug("{} is leaving {}", id, groupId);
 
         id.off("dispose", LEAVE);
 
@@ -344,6 +348,12 @@ public class GroupDispatcher implements ComponentHandle {
         stamps.remove(id);
 
         if (removed) {
+            GroupManager groupManager = GROUPMANAGER_REF.get();
+            if (groupManager == null) {
+                LOG.error("GroupManager reference unset.");
+            } else {
+                groupManager.remove(id, groupId);
+            }
             onLeave(id);
         }
 
@@ -352,7 +362,19 @@ public class GroupDispatcher implements ComponentHandle {
             properties.put("id", id);
             onDispose(id);
             isDisposed = true;
-            this.id.dispose(this, properties);
+            boolean isDisposable = groupId.dispose(this, properties);
+            /*
+             * If nobody vetoed the disposal of this GroupDispatcher we have to issue a cluster wide cleanup to remove entries from
+             * StanzaSequenceGate instances
+             */
+            if(isDisposable) {
+                GlobalRealtimeCleanup globalRealtimeCleanup = GroupServiceRegistry.getInstance().getService(GlobalRealtimeCleanup.class);
+                if(globalRealtimeCleanup == null) {
+                    LOG.error("Unable to initiate global cleanup for {} cleanup", id, ServiceExceptionCode.serviceUnavailable(GlobalRealtimeCleanup.class));
+                } else {
+                    globalRealtimeCleanup.cleanForId(groupId);
+                }
+            }
         }
     }
 
@@ -364,11 +386,12 @@ public class GroupDispatcher implements ComponentHandle {
     }
 
     /**
-     * Stamp a stanza with the selector for this recipient
+     * Stamp a stanza with the selector for this recipient. Furthermore this sets this GroupDispatcher as SequencePrincipal for this Stanza
+     * and uses the GroupDispatchers current sequence number for sending this Stanza.
      */
     public void stamp(Stanza s) {
         s.setSelector(getStamp(s.getTo()));
-        s.setSequencePrincipal(id);
+        s.setSequencePrincipal(groupId);
         s.setSequenceNumber(sequenceNumber.getAndIncrement());
     }
 
@@ -383,7 +406,7 @@ public class GroupDispatcher implements ComponentHandle {
      * Get the id of this group
      */
     public ID getId() {
-        return id;
+        return groupId;
     }
 
     /**
@@ -478,9 +501,7 @@ public class GroupDispatcher implements ComponentHandle {
      * Called for a stanza if no other handler is found.
      */
     protected void defaultAction(Stanza stanza) {
-        if (LOG.isErrorEnabled()) {
-            LOG.error("Couldn't find matching handler for " + stanza.toString() + ". \nUse default");
-        }
+        LOG.error("Couldn't find matching handler for {}. \nUse default", stanza);
     }
 
     private final IDEventHandler LEAVE = new IDEventHandler() {
@@ -490,7 +511,7 @@ public class GroupDispatcher implements ComponentHandle {
             try {
                 leave(id);
             } catch (OXException e) {
-                LOG.error("Error while handling LEAVE for ID:" + id, e);
+                LOG.error("Error while handling LEAVE for ID:{}", id, e);
             }
         }
     };
@@ -529,7 +550,7 @@ public class GroupDispatcher implements ComponentHandle {
 
     @Override
     public ID getID() {
-        return id;
+        return groupId;
     }
 
 }
