@@ -53,7 +53,12 @@ import com.openexchange.exception.OXException;
 import com.openexchange.realtime.dispatch.MessageDispatcher;
 import com.openexchange.realtime.group.GroupCommand;
 import com.openexchange.realtime.group.GroupDispatcher;
+import com.openexchange.realtime.group.osgi.GroupServiceRegistry;
+import com.openexchange.realtime.packet.ID;
 import com.openexchange.realtime.packet.Stanza;
+import com.openexchange.realtime.util.ActionHandler;
+import com.openexchange.threadpool.AbstractTask;
+import com.openexchange.threadpool.ThreadPoolService;
 
 
 /**
@@ -65,21 +70,46 @@ import com.openexchange.realtime.packet.Stanza;
 public class JoinCommand implements GroupCommand {
 
     @Override
-    public void perform(Stanza stanza, GroupDispatcher groupDispatcher) throws OXException {
+    public void perform(final Stanza stanza, final GroupDispatcher groupDispatcher) throws OXException {
         if (isSynchronous(stanza)) {
-            groupDispatcher.join(stanza.getOnBehalfOf(), stanza.getSelector());
-            Stanza welcomeMessage = groupDispatcher.getWelcomeMessage(stanza.getOnBehalfOf());
-            welcomeMessage.setFrom(groupDispatcher.getId());
-            welcomeMessage.setTo(stanza.getFrom());
-           
-            GroupDispatcher.SERVICE_REF.get().getService(MessageDispatcher.class).send(welcomeMessage);
+            if (shouldExecuteAsynchronously(groupDispatcher)) {
+                GroupServiceRegistry.getInstance().getService(ThreadPoolService.class).submit(new AbstractTask<Void>() {
+
+                    @Override
+                    public Void call() throws Exception {
+                        doWelcome(stanza, groupDispatcher);
+                        return null;
+                    }
+                });
+            } else {
+                doWelcome(stanza, groupDispatcher);
+            }
         } else {
             groupDispatcher.join(stanza.getFrom(), stanza.getSelector());
         }
     }
 
+    private void doWelcome(Stanza stanza, GroupDispatcher groupDispatcher) throws OXException {
+        groupDispatcher.join(stanza.getOnBehalfOf(), stanza.getSelector());
+        Stanza welcomeMessage = groupDispatcher.getWelcomeMessage(stanza.getOnBehalfOf());
+        welcomeMessage.setFrom(groupDispatcher.getId());
+        welcomeMessage.setTo(stanza.getFrom());
+         
+        GroupServiceRegistry.getInstance().getService(MessageDispatcher.class).send(welcomeMessage);
+    }
+
     private boolean isSynchronous(Stanza stanza) {
         return stanza.getFrom().getProtocol().equals("call");
     }
+    
+    private boolean shouldExecuteAsynchronously(GroupDispatcher groupDispatcher) {
+        try {
+            return ActionHandler.isAsynchronous(groupDispatcher.getClass().getMethod("getWelcomeMessage", ID.class));            
+        } catch (SecurityException e) {
+            return false;
+        } catch (NoSuchMethodException e) {
+            return false;
+        }
+    }
 
 }
