@@ -51,7 +51,6 @@ package com.openexchange.realtime.handle.impl.message;
 
 import java.util.Map;
 import java.util.concurrent.BlockingQueue;
-import org.apache.commons.logging.Log;
 import com.openexchange.exception.OXException;
 import com.openexchange.realtime.directory.Resource;
 import com.openexchange.realtime.directory.ResourceDirectory;
@@ -74,7 +73,7 @@ import com.openexchange.realtime.util.IDMap;
  */
 public class MessageHandler extends AbstractStrategyHandler<Message> {
 
-    private final static Log LOG = com.openexchange.log.Log.loggerFor(MessageHandler.class);
+    private final static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MessageHandler.class);
 
     public MessageHandler(BlockingQueue<Message> queue) {
         super(queue, new HandlerStrategy<Message>());
