@@ -56,7 +56,6 @@ import java.util.Map;
 import java.util.Map.Entry;
 import java.util.Set;
 import java.util.concurrent.TimeUnit;
-import org.apache.commons.logging.Log;
 import com.hazelcast.core.EntryEvent;
 import com.hazelcast.core.EntryListener;
 import com.hazelcast.core.HazelcastInstance;
@@ -84,14 +83,14 @@ import com.openexchange.timer.TimerService;
  * {@link HazelcastResourceDirectory} - Keeps mappings of general {@link ID}s to full {@link ID}s and full {@link ID}s to {@link Resource}.
  * New DefaultResources that are added to this directory are automatically converted to HazelcastResources and extended with the local
  * Hazelcast Member as routing info.
- * 
+ *
  * @author <a href="mailto:steffen.templin@open-xchange.com">Steffen Templin</a>
  * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
  */
 public class HazelcastResourceDirectory extends DefaultResourceDirectory implements ManagementAware<HazelcastResourceDirectoryMBean> {
 
     /** The logger */
-    static final Log LOG = com.openexchange.log.Log.loggerFor(HazelcastResourceDirectory.class);
+    static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(HazelcastResourceDirectory.class);
 
     /** Mapping of general IDs to full IDs e.g marc.arens@premium <-> ox://marc.arens@premuim/random. */
     private final String id_map;
@@ -106,7 +105,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
 
     /**
      * Initializes a new {@link HazelcastResourceDirectory}.
-     * 
+     *
      * @param id_map the name of the apping of general IDs to full IDs e.g marc.arens@premium <-> ox://marc.arens@premuim/random
      * @param resource_map the name of the mapping of full IDs to the Resource e.g. ox://marc.arens@premuim/random <-> ResourceMap
      * @throws OXException
@@ -127,10 +126,8 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
             public void entryRemoved(EntryEvent<String, Map<String, Serializable>> event) {
                 ID id = new ID(event.getKey());
                 boolean removed = syntheticIDs.remove(id);
-                if (LOG.isDebugEnabled()) {
-                    if (removed) {
-                        LOG.debug("Removed id from refresh list: " + id);
-                    }
+                if (removed) {
+                    LOG.debug("Removed id from refresh list: {}", id);
                 }
             }
 
@@ -145,18 +142,14 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
                 Member member = event.getMember();
                 try {
                     if (getIDMapping().remove(new ID(id).toGeneralForm().toString(), id)) {
-                        if (LOG.isDebugEnabled()) {
-                            LOG.debug("Source " + source + " on Member: " + member + " fired event. " + "Removing mapping for '" + id + "' due to eviction of according resource.");
-                        }
+                        LOG.debug("Source {} on Member: {} fired event. Removing mapping for '{}' due to eviction of according resource.", source, member, id);
                     }
                 } catch (OXException e) {
-                    LOG.warn("Could not handle eviction for id '" + id + "'", e);
+                    LOG.warn("Could not handle eviction for id '{}'", id, e);
                 }
                 boolean removed = syntheticIDs.remove(new ID(id));
-                if (LOG.isDebugEnabled()) {
-                    if (removed) {
-                        LOG.debug("Removed id from refresh list: " + id);
-                    }
+                if (removed) {
+                    LOG.debug("Removed id from refresh list: {}", id);
                 }
             }
         }, false);
@@ -258,9 +251,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
 
     @Override
     protected IDMap<Resource> doRemove(Collection<ID> ids) throws OXException {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Removing IDs from HazelcastResourceDirectory: " + ids);
-        }
+        LOG.debug("Removing IDs from HazelcastResourceDirectory: {}", ids);
         IDMap<Resource> removedResources = new IDMap<Resource>();
         Set<ID> generalIds = new HashSet<ID>();
         Set<ID> resourceIds = new HashSet<ID>();
@@ -306,17 +297,13 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
             tx.rollback();
             throw new OXException(t);
         }
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Removed Resource(s) from HazelcastResourceDirectory: " + removedResources);
-        }
+        LOG.debug("Removed Resource(s) from HazelcastResourceDirectory: {}", removedResources);
         return removedResources;
     }
 
     @Override
     protected IDMap<Resource> doRemove(ID id) throws OXException {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Removing ID from HazelcastResourceDirectory: " + id);
-        }
+        LOG.debug("Removing ID from HazelcastResourceDirectory: {}", id);
         IDMap<Resource> removedResources = new IDMap<Resource>();
         MultiMap<String, String> idMapping = getIDMapping();
         IMap<String, Map<String, Serializable>> allResources = getResourceMapping();
@@ -356,9 +343,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
                 throw new OXException(t);
             }
         }
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("Removed Resource(s) from HazelcastResourceDirectory: " + removedResources);
-        }
+        LOG.debug("Removed Resource(s) from HazelcastResourceDirectory: {}", removedResources);
         return removedResources;
     }
 
@@ -376,9 +361,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
         IMap<String, Map<String, Serializable>> allResources = getResourceMapping();
         HazelcastResource previousResource = null;
         Transaction tx = newTransaction();
-        if (LOG.isDebugEnabled()) {
-            LOG.debug(String.format("Starting transaction: %1$s for resource: %2$s", tx, hazelcastResource));
-        }
+        LOG.debug(String.format("Starting transaction: %1$s for resource: %2$s", tx, hazelcastResource));
         tx.begin();
         try {
             idMapping.put(id.toGeneralForm().toString(), id.toString());
@@ -411,14 +394,10 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
                 previousResource = HazelcastResourceWrapper.unwrap(previousResourceMap);
             }
 
-            if (LOG.isDebugEnabled()) {
-                LOG.debug(String.format("Committing transaction %1$s for resource %2$s", tx, hazelcastResource));
-            }
+            LOG.debug(String.format("Committing transaction %1$s for resource %2$s", tx, hazelcastResource));
             tx.commit();
         } catch (Throwable t) {
-            if (LOG.isDebugEnabled()) {
-                LOG.debug(String.format("Rolling back transaction: %1$s for resource: %2$s", tx, hazelcastResource));
-            }
+            LOG.debug(String.format("Rolling back transaction: %1$s for resource: %2$s", tx, hazelcastResource));
             tx.rollback();
             throw new OXException(t);
         }
@@ -447,7 +426,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
 
     /**
      * Try to create a new HazelcastResource for the given ID. One place where this is used is during creation of GroupDispatchers.
-     * 
+     *
      * @param id The ID used to reach a Resource
      * @return null if the HazelcastResource couldn't be created, otherwise the new Resource
      * @throws OXException
@@ -479,7 +458,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
 
     /**
      * Get the mapping of general IDs to full IDs e.g. marc.arens@premium <-> ox://marc.arens@premium/random.
-     * 
+     *
      * @return the map used for mapping general IDs to full IDs.
      * @throws OXException if the HazelcastInstance is missing.
      */
@@ -490,7 +469,7 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
 
     /**
      * Get the mapping of full IDs to the Resource e.g. ox://marc.arens@premuim/random <-> ResourceMap.
-     * 
+     *
      * @return the map used for mapping full IDs to ResourceMaps.
      * @throws OXException if the map couldn't be fetched from hazelcast
      */
@@ -499,6 +478,12 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
         return hazelcast.getMap(resource_map);
     }
 
+    /**
+     * Creates a new transaction.
+     *
+     * @return The newly created transaction
+     * @throws OXException If an error occurs while creating the transaction
+     */
     protected static Transaction newTransaction() throws OXException {
         /*
          * HazelcastInstance hazelcast = HazelcastAccess.getHazelcastInstance(); return hazelcast.getTransaction();
@@ -553,11 +538,9 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
             if (source != HazelcastResourceDirectory.this) {
                 try {
                     IDMap<Resource> removed = removeWithoutDisposeEvent(id);
-                    if (LOG.isDebugEnabled()) {
-                        LOG.debug("Removed: " + removed.entrySet().toString());
-                    }
+                    LOG.debug("Removed: {}", removed.entrySet());
                 } catch (OXException e) {
-                    LOG.error(e.getMessage(), e);
+                    LOG.error("", e);
                 }
             }
         }
@@ -579,17 +562,15 @@ public class HazelcastResourceDirectory extends DefaultResourceDirectory impleme
                 getIDMapping().get(id.toGeneralForm().toString());
                 Map<String, Serializable> resourceWrap = getResourceMapping().get(id.toString());
                 if (resourceWrap == null) {
-                    if (LOG.isDebugEnabled()) {
-                        LOG.debug("Unable to refresh id, might have been removed in the meantime: " + id);
-                    }
+                    LOG.debug("Unable to refresh id, might have been removed in the meantime: {}", id);
                     syntheticIDs.remove(id);
                 } else {
                     resourceWrap.put(HazelcastResourceWrapper.eviction_timestamp, System.currentTimeMillis());
                     Map<String, Serializable> put = getResourceMapping().put(id.toString(), resourceWrap);
                     if (put == null) {
-                        LOG.warn("There was no previous entry associated with id: " + id + "when refreshing the directory entry via write.");
+                        LOG.warn("There was no previous entry associated with id: {}when refreshing the directory entry via write.", id);
                     } else {
-                        LOG.debug("Refreshed id: " + id.toString() + " with resource: " + resourceWrap);
+                        LOG.debug("Refreshed id: {} with resource: {}", id, resourceWrap);
                     }
                 }
             } catch (OXException e) {
