@@ -56,7 +56,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArrayList;
-import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReentrantLock;
 import com.openexchange.exception.OXException;
@@ -342,13 +341,40 @@ public class ID implements Serializable {
         if (needSep) {
             b.append("://");
         }
-        b.append(user).append('@').append(context);
+        b.append(escape(user, '@')).append('@').append(escape(context, '@','/'));
         if (resource != null) {
             b.append('/').append(resource);
         }
         return b.toString();
     }
 
+    /**
+     * If the given input string contains any of the candidate characters those will be escaped via '\'
+     * @param str The input string
+     * @param chars The characters to escape in the input string 
+     * @return The given input string with the candidate characters escaped via '\'
+     */
+    private String escape(String str, char...chars) {
+        StringBuilder b = new StringBuilder();
+        for(char c: str.toCharArray()) {
+            boolean escape = false;
+            if (c == '\\') {
+                escape = true;
+            } else {
+                for(char candidate: chars) {
+                    if (candidate == c) {
+                        escape = true;
+                    }
+                }
+            }
+            if (escape) {
+                b.append('\\');
+            }
+            b.append(c);
+        }
+        return b.toString();
+    }
+
     /**
      * Strip protocol and resource from this id so that it only contains user@context information.
      *
@@ -368,15 +394,19 @@ public class ID implements Serializable {
         return null == protocol && null == resource;
     }
 
+    /**
+     * Create a ServerSession from a dummy SessionObject based on the user infos contained in this {@link ID}. This will fail for synthetic
+     * {@link ID}s that don't have real userId and userContextId values.
+     * 
+     * @return a ServerSession from a dummy SessionObject based on the user infos contained in this {@link ID}.
+     * @throws OXException if no ServerSession can be ceated based upon thi {@link ID}.
+     */
     public ServerSession toSession() throws OXException {
         UserAndContext userAndContextIDs = IdLookup.getUserAndContextIDs(this);
-        if (userAndContextIDs != null) {
-            return ServerSessionAdapter.valueOf(SessionObjectWrapper.createSessionObject(
-                userAndContextIDs.getUserId(),
-                userAndContextIDs.getContextId(),
-                (resource != null) ? resource : "rt"));
-        }
-        SessionObject sessionObject = new SessionObject("anonymous");
+        SessionObject sessionObject = SessionObjectWrapper.createSessionObject(
+            userAndContextIDs.getUserId(),
+            userAndContextIDs.getContextId(),
+            (resource != null) ? resource : "rt");
         return ServerSessionAdapter.valueOf(sessionObject);
     }
 
@@ -499,11 +529,18 @@ public class ID implements Serializable {
 
         return lock;
     }
-    
-    public void dispose(Object source, Map<String, Object> properties) {
+
+    /**
+     * Dispose this ID.
+     * 
+     * @param source The event source
+     * @param properties The event properties
+     * @return False if the ID wasn't disposed due to a veto or an ongoing dispose call
+     */
+    public boolean dispose(Object source, Map<String, Object> properties) {
         Boolean currentValue = DISPOSING.putIfAbsent(this, Boolean.TRUE);
         if (currentValue == Boolean.TRUE) {
-            return;
+            return false;
         }
         try {
             Map<String, Object> vetoProperties = new HashMap<String, Object>();
@@ -511,7 +548,9 @@ public class ID implements Serializable {
             Boolean veto = (Boolean) vetoProperties.get("veto");
             if (veto == null || !veto) {
                 this.trigger(Events.DISPOSE, source, properties);
+                return true;
             }
+            return false;
         } finally {
             DISPOSING.remove(this);
         }
