@@ -58,11 +58,12 @@ import com.openexchange.realtime.packet.Stanza;
  * {@link MessageDispatch}
  *
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
+ * @author <a href="mailto:marc.arens@open-xchange.com">Marc Arens</a>
  */
 public class MessageDispatch {
     
     private ComponentHandle handle;
-    private Stanza stanza;
+    private final Stanza stanza;
     
     public MessageDispatch(ComponentHandle handle, Stanza stanza) {
         super();
@@ -75,4 +76,23 @@ public class MessageDispatch {
         handle.process(stanza);
     }
 
+    
+    /**
+     * Gets the handle
+     *
+     * @return The handle
+     */
+    public ComponentHandle getHandle() {
+        return handle;
+    }
+
+    /**
+     * Sets the handle
+     *
+     * @param handle The handle to set
+     */
+    public void setHandle(ComponentHandle handle) {
+        this.handle = handle;
+    }
+
 }
